
/* Generated data (by glib-mkenums) */

/*
 * Copyright (C) 2012 Marc-André Lureau <marcandre.lureau@redhat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GCAB_ENUMS_H
#define GCAB_ENUMS_H

#include <glib-object.h>

G_BEGIN_DECLS
GType gcab_compression_get_type (void) G_GNUC_CONST;
#define GCAB_TYPE_COMPRESSION (gcab_compression_get_type ())
GType gcab_file_attribute_get_type (void) G_GNUC_CONST;
#define GCAB_TYPE_FILE_ATTRIBUTE (gcab_file_attribute_get_type ())
G_END_DECLS

#endif

/* Generated data ends here */

